<!-- asdf-vm homepage -->

<!-- include the repo readme -->
[](https://raw.githubusercontent.com/asdf-vm/asdf/master/README.md ':include')

<!-- include the ballad of asdf-vm -->
[](https://raw.githubusercontent.com/asdf-vm/asdf/master/ballad-of-asdf.md ':include')
